#!/usr/bin/env python3

import sys
import numpy as np
import pandas as pd
from pandas_ods_reader import read_ods


sl_sector = sys.argv[1]

# this program expects that there is a file called file_list_extra.txt that contains all of the files that will be merged

file_list_filename = sl_sector + "/file_list_extra.txt"

try:
	file_list = open(file_list_filename, "r")
	files = file_list.readlines()
	file_list.close()
except FileNotFoundError:
	print("No extra files are detected")
	sys.exit()




# it is expected that the ods file contains a sheet called sea_level that will contain the desired data
sheet_name = "sea_level"

# create a pandas dataframe



counter=1

for file_line in files:
	split_line = file_line.split('\t')
	file_name = sl_sector + "/" + split_line[0]
	folder_extension = split_line[1]
	latex_extension = split_line[2]
	gmt_extension = split_line[3].strip()
	try:
		sl_data = read_ods(file_name, sheet_name, headers=True)
		output_dataframe = pd.DataFrame(columns=['Region','Dating_Method','LAB_ID','Latitude','Longitude','age','error','Material','Curve','Reservoir_age','Reservoir_error','type','RSL','RSL_2sigma_upper','RSL_2sigma_lower','Reference'])
		output_dataframe= pd.DataFrame(pd.concat([output_dataframe,sl_data]), columns=output_dataframe.columns)

		output_dataframe = output_dataframe.fillna("")

		file_out_prefix = "merge_extra_" + str(counter)

		file_out_ods = sl_sector + "/temp/" + file_out_prefix + ".ods"

		with pd.ExcelWriter(file_out_ods, engine="odf") as doc:
			output_dataframe.to_excel(doc, sheet_name=sheet_name, index=False)

		file_out_csv = sl_sector + "/temp/" + file_out_prefix + ".csv"

		output_dataframe.to_csv(file_out_csv, index=False, sep = '\t')

		file_out_csv = sl_sector + "/temp/" + file_out_prefix + "_points.txt"

		output_dataframe.to_csv(file_out_csv, index=False, sep=" ", columns=['Longitude','Latitude'], header=False)
	except KeyError:
		print(f"There is no sheet called \"sea_level\" in the file: {file_name}")
		print("skipping for now")

	counter = counter + 1
